/*
 * Copyright (c) 2014, 2015, 2016 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.math.BigDecimal;
import java.util.List;
import java.util.regex.Pattern;

/**
 * Builds an {@link AapConfiguration}.
 */
class AapConfigurationBuilder {
  private AapConfiguration defaults = null;
  private Integer maxNumProcessJobs = null;
  private Integer maxNumIndexJobs = null;
  private Integer maxNumRegisterJobs = null;
  private Integer maxNumDirChangeJobs = null;
  private Boolean fsPollEnabled = null;
  private TimeDuration fsPollPeriod = null;
  private Integer fsPollMaxNumJobs = null;
  private Boolean fsPollMetadataEnabled = null;
  private Pattern processingDirPat = null;
  private Pattern diffCenterImagePat = null;
  private Pattern imagePat = null;
  private String processingDirName = null;
  private TimeDuration datasetSettleTime = null;
  private Integer datasetMinNumImages = null;
  private Boolean perTreeResultsEnabled = null;
  private TimeDuration maxProcessRunTime = null;
  private TimeDuration processSupervisorPeriod = null;
  private BigDecimal maxRefinedDetDistDelta = null;
  private Integer numThreadsPerProcessJob = null;
  private Pattern excludeDirPat = null;
  private List<String> postProcessHook = null;

  public AapConfigurationBuilder() {
    super();
  }

  public AapConfiguration defaults() {
    return defaults;
  }

  public void defaults(AapConfiguration newDefaults) {
    defaults = newDefaults;
  }

  public Integer maxNumProcessJobs() {
    return maxNumProcessJobs;
  }

  public void maxNumProcessJobs(Integer newMaxNumProcessJobs) {
    maxNumProcessJobs = newMaxNumProcessJobs;
  }

  public Integer maxNumIndexJobs() {
    return maxNumIndexJobs;
  }

  public void maxNumIndexJobs(Integer newMaxNumIndexJobs) {
    maxNumIndexJobs = newMaxNumIndexJobs;
  }

  public Integer maxNumRegisterJobs() {
    return maxNumRegisterJobs;
  }

  public void maxNumRegisterJobs(Integer newMaxNumRegisterJobs) {
    maxNumRegisterJobs = newMaxNumRegisterJobs;
  }

  public Integer maxNumDirChangeJobs() {
    return maxNumDirChangeJobs;
  }

  public void maxNumDirChangeJobs(Integer newMaxNumDirChangeJobs) {
    maxNumDirChangeJobs = newMaxNumDirChangeJobs;
  }

  public Boolean fsPollEnabled() {
    return fsPollEnabled;
  }

  public void fsPollEnabled(Boolean newFsPollEnabled) {
    fsPollEnabled = newFsPollEnabled;
  }

  public TimeDuration fsPollPeriod() {
    return fsPollPeriod;
  }

  public void fsPollPeriod(TimeDuration newFsPollPeriod) {
    fsPollPeriod = newFsPollPeriod;
  }

  public Integer fsPollMaxNumJobs() {
    return fsPollMaxNumJobs;
  }

  public void fsPollMaxNumJobs(Integer newFsPollMaxNumJobs) {
    fsPollMaxNumJobs = newFsPollMaxNumJobs;
  }

  public Boolean fsPollMetadataEnabled() {
    return fsPollMetadataEnabled;
  }

  public void fsPollMetadataEnabled(Boolean newFsPollMetadataEnabled) {
    fsPollMetadataEnabled = newFsPollMetadataEnabled;
  }

  public Pattern processingDirPat() {
    return processingDirPat;
  }

  public void processingDirPat(Pattern newProcessingDirPat) {
    processingDirPat = newProcessingDirPat;
  }

  public Pattern diffCenterImagePat() {
    return diffCenterImagePat;
  }

  public void diffCenterImagePat(Pattern newDiffCenterImagePat) {
    diffCenterImagePat = newDiffCenterImagePat;
  }

  public Pattern imagePat() {
    return imagePat;
  }

  public void imagePat(Pattern newImagePat) {
    imagePat = newImagePat;
  }

  public String processingDirName() {
    return processingDirName;
  }

  public void processingDirName(String newProcessingDirName) {
    processingDirName = newProcessingDirName;
  }

  public TimeDuration datasetSettleTime() {
    return datasetSettleTime;
  }

  public void datasetSettleTime(TimeDuration newDatasetSettleTime) {
    datasetSettleTime = newDatasetSettleTime;
  }

  public Integer datasetMinNumImages() {
    return datasetMinNumImages;
  }

  public void datasetMinNumImages(Integer newDatasetMinNumImages) {
    datasetMinNumImages = newDatasetMinNumImages;
  }

  public Boolean perTreeResultsEnabled() {
    return perTreeResultsEnabled;
  }

  public void perTreeResultsEnabled(Boolean newPerTreeResultsEnabled) {
    perTreeResultsEnabled = newPerTreeResultsEnabled;
  }

  public TimeDuration maxProcessRunTime() {
    return maxProcessRunTime;
  }

  public void maxProcessRunTime(TimeDuration newMaxProcessRunTime) {
    maxProcessRunTime = newMaxProcessRunTime;
  }

  public TimeDuration processSupervisorPeriod() {
    return processSupervisorPeriod;
  }

  public void processSupervisorPeriod(TimeDuration newProcessSupervisorPeriod) {
    processSupervisorPeriod = newProcessSupervisorPeriod;
  }

  public BigDecimal maxRefinedDetDistDelta() {
    return maxRefinedDetDistDelta;
  }

  public void maxRefinedDetDistDelta(BigDecimal newMaxRefinedDetDistDelta) {
    maxRefinedDetDistDelta = newMaxRefinedDetDistDelta;
  }

  public Integer numThreadsPerProcessJob() {
    return numThreadsPerProcessJob;
  }

  public void numThreadsPerProcessJob(Integer newNumThreadsPerProcessJob) {
    numThreadsPerProcessJob = newNumThreadsPerProcessJob;
  }

  public Pattern excludeDirPat() {
    return excludeDirPat;
  }

  public void excludeDirPat(Pattern newExcludeDirPat) {
    excludeDirPat = newExcludeDirPat;
  }

  public List<String> postProcessHook() {
    return postProcessHook;
  }

  public void postProcessHook(List<String> newPostProcessHook) {
    postProcessHook = newPostProcessHook;
  }

  public AapConfiguration toAapConfiguration() {
    if (defaults == null) {
      return new AapConfiguration(maxNumProcessJobs, maxNumIndexJobs, maxNumRegisterJobs,
          maxNumDirChangeJobs, fsPollEnabled, fsPollPeriod, fsPollMaxNumJobs, fsPollMetadataEnabled,
          processingDirPat, diffCenterImagePat, imagePat, processingDirName, datasetSettleTime,
          datasetMinNumImages, perTreeResultsEnabled, maxProcessRunTime, processSupervisorPeriod,
          maxRefinedDetDistDelta, numThreadsPerProcessJob, excludeDirPat, postProcessHook);
    } else {
      return new AapConfiguration(defaults, maxNumProcessJobs, maxNumIndexJobs, maxNumRegisterJobs,
          maxNumDirChangeJobs, fsPollEnabled, fsPollPeriod, fsPollMaxNumJobs, fsPollMetadataEnabled,
          processingDirPat, diffCenterImagePat, imagePat, processingDirName, datasetSettleTime,
          datasetMinNumImages, perTreeResultsEnabled, maxProcessRunTime, processSupervisorPeriod,
          maxRefinedDetDistDelta, numThreadsPerProcessJob, excludeDirPat, postProcessHook);
    }
  }
}
