/*
 * Copyright (c) 2014, 2015 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

/**
 * Provides access to Aaproc system resources. Anything that would want to use
 * {@code java.lang.System}, {@code java.lang.Runtime}, or similar should
 * instead use this class. This is an abstraction that makes it easy to provide
 * an alternate implementation (e.g. for testing).
 */
abstract class AaprocSystem {
  public static final String DB_FILE_NAME = ".aaproc_db";

  private static AaprocSystem defaultSystem = new RegularAaprocSystem();

  /**
   * Gets the {@link Aap} autoPROC helper executable path.
   *
   * @return {@link Aap} autoPROC helper executable path
   */
  public abstract String aapAutoprocHelperPath();

  /**
   * Gets the system-wide configuration file path.
   *
   * @return system-wide configuration file path
   */
  public abstract String sysConfFilePath();

  /**
   * Gets the current user's home directory path.
   *
   * @return user's home directory path
   */
  public abstract String userHomeDirectory();

  /**
   * Gets the current user's current working directory path.
   *
   * @return user's current working directory path
   */
  public abstract String userCurrentWorkingDirectory();

  /**
   * Gets the version string.
   *
   * @return version string
   */
  public abstract String version();

  public static AaprocSystem getDefault() {
    return defaultSystem;
  }
}
