/*
 * Copyright (c) 2014, 2015 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.math.BigDecimal;
import java.util.Objects;

/**
 * The result of processing a dataset.
 */
class DatasetProcessResult {
  private final Dataset dataset;
  private final Throwable exception;
  private final BigDecimal lowResolution;
  private final BigDecimal highResolution;
  private final BigDecimal rMerge;
  private final BigDecimal iOverSigma;
  private final BigDecimal completeness;
  private final BigDecimal multiplicity;
  private final UnitCell unitCell;
  private final String spaceGroup;

  public DatasetProcessResult(Dataset dataset, Throwable exception) {
    this(dataset, exception, null, null, null, null, null, null, null, null);
  }

  public DatasetProcessResult(Dataset dataset, Throwable exception, BigDecimal lowResolution,
      BigDecimal highResolution, BigDecimal rMerge, BigDecimal iOverSigma, BigDecimal completeness,
      BigDecimal multiplicity, UnitCell unitCell, String spaceGroup) {
    super();
    this.dataset = Objects.requireNonNull(dataset);
    this.exception = exception;
    this.lowResolution = lowResolution;
    this.highResolution = highResolution;
    this.rMerge = rMerge;
    this.iOverSigma = iOverSigma;
    this.completeness = completeness;
    this.multiplicity = multiplicity;
    this.unitCell = unitCell;
    this.spaceGroup = spaceGroup;
  }

  public Dataset dataset() {
    return dataset;
  }

  public Throwable exception() {
    return exception;
  }

  public boolean hasException() {
    return exception != null;
  }

  public boolean succeeded() {
    return exception == null;
  }

  public BigDecimal lowResolution() {
    return lowResolution;
  }

  public BigDecimal highResolution() {
    return highResolution;
  }

  public BigDecimal rMerge() {
    return rMerge;
  }

  public BigDecimal iOverSigma() {
    return iOverSigma;
  }

  public BigDecimal completeness() {
    return completeness;
  }

  public BigDecimal multiplicity() {
    return multiplicity;
  }

  public UnitCell unitCell() {
    return unitCell;
  }

  public String spaceGroup() {
    return spaceGroup;
  }

  @Override
  public String toString() {
    StringBuilder b = new StringBuilder();
    b.append(succeeded() ? "OK" : "FAILED");
    b.append(": ");
    b.append(dataset);
    return b.toString();
  }
}
