/*
 * Copyright (c) 2014 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.math.BigDecimal;

/**
 * Builds a {@link DatasetProcessResult}.
 */
class DatasetProcessResultBuilder {
  private Dataset dataset;
  private Throwable exception;
  private BigDecimal lowResolution;
  private BigDecimal highResolution;
  private BigDecimal rMerge;
  private BigDecimal iOverSigma;
  private BigDecimal completeness;
  private BigDecimal multiplicity;
  private UnitCell unitCell;
  private String spaceGroup;

  public DatasetProcessResultBuilder() {
    super();
  }

  public Dataset dataset() {
    return dataset;
  }

  public void dataset(Dataset dataset) {
    this.dataset = dataset;
  }

  public Throwable exception() {
    return exception;
  }

  public void exception(Throwable exception) {
    this.exception = exception;
  }

  public BigDecimal lowResolution() {
    return lowResolution;
  }

  public void lowResolution(BigDecimal lowResolution) {
    this.lowResolution = lowResolution;
  }

  public BigDecimal highResolution() {
    return highResolution;
  }

  public void highResolution(BigDecimal highResolution) {
    this.highResolution = highResolution;
  }

  public BigDecimal rMerge() {
    return rMerge;
  }

  public void rMerge(BigDecimal rMerge) {
    this.rMerge = rMerge;
  }

  public BigDecimal iOverSigma() {
    return iOverSigma;
  }

  public void iOverSigma(BigDecimal iOverSigma) {
    this.iOverSigma = iOverSigma;
  }

  public BigDecimal completeness() {
    return completeness;
  }

  public void completeness(BigDecimal completeness) {
    this.completeness = completeness;
  }

  public BigDecimal multiplicity() {
    return multiplicity;
  }

  public void multiplicity(BigDecimal multiplicity) {
    this.multiplicity = multiplicity;
  }

  public UnitCell unitCell() {
    return unitCell;
  }

  public void unitCell(UnitCell unitCell) {
    this.unitCell = unitCell;
  }

  public String spaceGroup() {
    return spaceGroup;
  }

  public void spaceGroup(String spaceGroup) {
    this.spaceGroup = spaceGroup;
  }

  public boolean hasAnyProcessValues() {
    return lowResolution != null || highResolution != null || rMerge != null ||
        iOverSigma != null || completeness != null || multiplicity != null || unitCell != null ||
        spaceGroup != null;
  }

  public DatasetProcessResult toDatasetProcessResult() {
    return new DatasetProcessResult(dataset, exception, lowResolution, highResolution, rMerge,
        iOverSigma, completeness, multiplicity, unitCell, spaceGroup);
  }
}
