/*
 * Copyright (c) 2014 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.nio.file.Path;

/**
 * A result representing a found dataset produced by a
 * {@link DatasetWatchService}.
 */
class DatasetWatchResult {
  private final Dataset dataset;
  private final Path invalidTreeRoot;

  public DatasetWatchResult(Path invalidTreeRoot) {
    this(null, invalidTreeRoot);
  }

  public DatasetWatchResult(Dataset dataset) {
    this(dataset, null);
  }

  public DatasetWatchResult(Dataset dataset, Path invalidTreeRoot) {
    super();
    this.dataset = dataset;
    this.invalidTreeRoot = invalidTreeRoot;
    if (this.dataset == null && this.invalidTreeRoot == null) {
      throw new IllegalArgumentException("dataset and invalidTreeRoot are both null");
    }
    if (this.dataset != null && this.invalidTreeRoot != null) {
      throw new IllegalArgumentException("dataset and invalidTreeRoot are both nonnull");
    }
  }

  public boolean isDataset() {
    return dataset != null;
  }

  /**
   * @throws IllegalStateException if not a dataset result
   */
  public Dataset dataset() {
    if (!isDataset()) {
      throw new IllegalStateException("Not a dataset");
    }
    return dataset;
  }

  public boolean isInvalidTreeRoot() {
    return invalidTreeRoot != null;
  }

  /**
   * @throws IllegalStateException if not an invalid tree root result
   */
  public Path invalidTreeRoot() {
    if (!isInvalidTreeRoot()) {
      throw new IllegalStateException("Not an invalid tree root");
    }
    return invalidTreeRoot;
  }
}
