/*
 * Copyright (c) 2015 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.util.Objects;

/**
 * An object holding two objects.
 *
 * @param <T> the type of the first object
 * @param <S> the type of the second object
 */
class Pair<T, S> {
  private final T o1;
  private final S o2;

  public Pair(T o1, S o2) {
    super();
    this.o1 = o1;
    this.o2 = o2;
  }

  public T first() {
    return o1;
  }

  public boolean hasFirst() {
    return o1 != null;
  }

  public S second() {
    return o2;
  }

  public boolean hasSecond() {
    return o2 != null;
  }

  @Override
  public boolean equals(Object o) {
    if (o == this) return true;
    if (!(o instanceof Pair<?, ?>)) return false;
    Pair<?, ?> p = (Pair<?, ?>)o;
    if (!Objects.equals(o1, p.o1)) return false;
    if (!Objects.equals(o2, p.o2)) return false;
    return true;
  }

  @Override
  public int hashCode() {
    int result = 17;
    result = 31 * result + ((o1 == null) ? 0 : o1.hashCode());
    result = 31 * result + ((o2 == null) ? 0 : o2.hashCode());
    return result;
  }

  @Override
  public String toString() {
    StringBuilder b = new StringBuilder();
    b.append("o1=");
    b.append(o1);
    b.append(", o2=");
    b.append(o2);
    return b.toString();
  }
}
