/*
 * Copyright (c) 2015 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.util.concurrent.Callable;

/**
 * A callable that can return a result of one of two types by way of a holder
 * {@code Pair} result object.
 *
 * @param <T> the type of the first pair object
 * @param <S> the type of the second pair object
 *
 * @see Pair
 */
class PairCallable<T, S> implements Callable<Pair<T, S>> {
  private final Callable<T> c1;
  private final Callable<S> c2;

  public PairCallable(Callable<T> c1, Callable<S> c2) {
    super();
    if ((c1 == null && c2 == null) || (c1 != null && c2 != null)) {
      throw new IllegalArgumentException("Arguments are both null or nonnull");
    }
    this.c1 = c1;
    this.c2 = c2;
  }

  @Override
  public Pair<T, S> call() throws Exception {
    if (c1 != null) {
      return new Pair<T, S>(c1.call(), null);
    } else {
      return new Pair<T, S>(null, c2.call());
    }
  }

  @Override
  public String toString() {
    StringBuilder b = new StringBuilder();
    b.append("c1=");
    b.append(c1);
    b.append(", c2=");
    b.append(c2);
    return b.toString();
  }
}
