/*
 * Copyright (c) 2014 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * An {@code AaprocSystem} that gets values from the {@code aaproc.properties}
 * resource or the core Java library. This is the {@code AaprocSystem} that is
 * normally used for a regular program run.
 */
class RegularAaprocSystem extends AaprocSystem {
  private static Properties config = null;

  public RegularAaprocSystem() {
    super();
  }

  @Override
  public String aapAutoprocHelperPath() {
    return configuration().getProperty("aapAutoprocHelperPath");
  }

  @Override
  public String sysConfFilePath() {
    return configuration().getProperty("sysConfFilePath");
  }

  @Override
  public String userHomeDirectory() {
    return System.getProperty("user.home");
  }

  @Override
  public String userCurrentWorkingDirectory() {
    return System.getProperty("user.dir");
  }

  @Override
  public String version() {
    return configuration().getProperty("version");
  }

  private synchronized static Properties configuration() {
    if (config == null) {
      try (InputStream s = RegularAaprocSystem.class.getResourceAsStream("/aaproc.properties")) {
        Properties p = new Properties();
        p.load(s);
        config = p;
      } catch (IOException e) {
        throw new RuntimeException("Unable to load built-in configuration", e);
      }
    }
    return config;
  }
}
