/*
 * Copyright (c) 2015 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.math.BigDecimal;

/**
 * The result of <a href="http://xds.mpimf-heidelberg.mpg.de/">XDS</a>
 * integration of a dataset.
 */
class XdsIntegrateResult {
  private final Throwable exception;
  private final boolean failedToRefine;
  private final BigDecimal detDist;
  private final BigDecimal refinedDetDist;

  public XdsIntegrateResult(Throwable exception) {
    this(exception, false, null, null);
  }

  public XdsIntegrateResult(Throwable exception, boolean failedToRefine, BigDecimal detDist,
      BigDecimal refinedDetDist) {
    super();
    this.exception = exception;
    this.failedToRefine = failedToRefine;
    this.detDist = detDist;
    this.refinedDetDist = refinedDetDist;
  }

  public Throwable exception() {
    return exception;
  }

  public boolean hasException() {
    return exception != null;
  }

  public boolean failedToRefine() {
    return failedToRefine;
  }

  public BigDecimal detectorDistance() {
    return detDist;
  }

  public BigDecimal refinedDetectorDistance() {
    return refinedDetDist;
  }

  public BigDecimal refinedDetectorDistanceDelta() {
    if (detDist == null) return null;
    if (refinedDetDist == null) return null;
    return refinedDetDist.subtract(detDist).abs();
  }

  @Override
  public String toString() {
    StringBuilder b = new StringBuilder();
    b.append("exception=");
    b.append(exception);
    b.append(", failedToRefine=");
    b.append(failedToRefine);
    b.append(", detDist=");
    b.append(detDist);
    b.append(", refinedDetDist=");
    b.append(refinedDetDist);
    return b.toString();
  }
}
