/*
 * Copyright (c) 2015 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import java.math.BigDecimal;

/**
 * Builds a {@link XdsIntegrateResult}.
 */
class XdsIntegrateResultBuilder {
  private Throwable exception;
  private Boolean failedToRefine;
  private BigDecimal detectorDistance;
  private BigDecimal refinedDetectorDistance;

  public XdsIntegrateResultBuilder() {
    super();
  }

  public Throwable exception() {
    return exception;
  }

  public void exception(Throwable exception) {
    this.exception = exception;
  }

  public Boolean failedToRefine() {
    return failedToRefine;
  }

  public void failedToRefine(Boolean failedToRefine) {
    this.failedToRefine = failedToRefine;
  }

  public BigDecimal detectorDistance() {
    return detectorDistance;
  }

  public void detectorDistance(BigDecimal detectorDistance) {
    this.detectorDistance = detectorDistance;
  }

  public BigDecimal refinedDetectorDistance() {
    return refinedDetectorDistance;
  }

  public void refinedDetectorDistance(BigDecimal refinedDetectorDistance) {
    this.refinedDetectorDistance = refinedDetectorDistance;
  }

  public boolean hasAnyIntegrateValues() {
    return detectorDistance != null || refinedDetectorDistance != null;
  }

  public XdsIntegrateResult toXdsIntegrateResult() {
    return new XdsIntegrateResult(exception,
        failedToRefine == null ? false : failedToRefine.booleanValue(), detectorDistance,
        refinedDetectorDistance);
  }
}
