/*
 * Copyright (c) 2014 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Arrays;
import java.util.Collections;

import org.imca_cat.prgm.ProgramArgumentsParseException;
import org.junit.Test;

/**
 * Tests {@link AapArgumentsParser}.
 */
public class AapArgumentsParserTest {
  public AapArgumentsParserTest() {
    super();
  }

  @Test
  public void testStackTrace() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Arrays.asList("-s"));
    assertTrue(a.hasStackTraceOption());
  }

  @Test
  public void testVerbose() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Arrays.asList("-v"));
    assertTrue(a.hasVerboseOption());
  }

  @Test
  public void testVersion() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Arrays.asList("-V"));
    assertTrue(a.hasVersionOption());
  }

  @Test
  public void testConfFile() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Arrays.asList("-f", "x.conf"));
    assertTrue(a.hasConfFile());
    assertEquals("x.conf", a.confFile());
  }

  @Test
  public void testMaxNumProcessJobs() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Arrays.asList("-j", "23"));
    assertTrue(a.hasMaxNumProcessJobs());
    assertEquals(23, a.maxNumProcessJobs().intValue());
  }

  @Test(expected = ProgramArgumentsParseException.class)
  public void testMaxNumProcessJobs_invalid() throws ProgramArgumentsParseException {
    AapArgumentsParser.parse(Arrays.asList("-j", "x"));
  }

  @Test
  public void testDirectories() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Arrays.asList("a", "b", "c"));
    assertEquals(Arrays.asList("a", "b", "c"), a.directories());
  }

  @Test
  public void testDirectories_empty() throws ProgramArgumentsParseException {
    AapArguments a = AapArgumentsParser.parse(Collections.<String>emptyList());
    assertEquals(Collections.<String>emptyList(), a.directories());
  }
}
