/*
 * Copyright (c) 2014, 2015, 2016 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.regex.Pattern;

import org.junit.Test;

/**
 * Tests {@link AapConfiguration}.
 */
public class AapConfigurationTest {
  public AapConfigurationTest() {
    super();
  }

  @Test
  public void testDefaults_gettersGetDefaults() {
    AapConfiguration defaults = new AapConfiguration(null, 1, 2, 3, 4, Boolean.TRUE,
        TimeDuration.seconds(5), 6, Boolean.FALSE, Pattern.compile("a"), Pattern.compile("b"),
        Pattern.compile("c"), "processing1", TimeDuration.seconds(7), 8, Boolean.TRUE,
        TimeDuration.seconds(9), TimeDuration.seconds(10), new BigDecimal("11"), 12,
        Pattern.compile("d"), Arrays.asList("e"));
    AapConfiguration c = new AapConfiguration(defaults, null, null, null, null, null, null, null,
        null, null, null, null, null, null, null, null, null, null, null, null, null, null);
    assertEquals(1, c.maxNumProcessJobs());
    assertEquals(2, c.maxNumIndexJobs());
    assertEquals(3, c.maxNumRegisterJobs());
    assertEquals(4, c.maxNumDirChangeJobs());
    assertTrue(c.fileSystemPollEnabled());
    assertEquals(TimeDuration.seconds(5), c.fileSystemPollPeriod());
    assertEquals(6, c.fileSystemPollMaxNumJobs());
    assertFalse(c.fileSystemPollMetadataEnabled());
    assertEquals("a", c.processingDirPat().pattern());
    assertEquals("b", c.diffCenterImagePat().pattern());
    assertEquals("c", c.imagePat().pattern());
    assertEquals("processing1", c.processingDirName());
    assertEquals(TimeDuration.seconds(7), c.datasetSettleTime());
    assertEquals(8, c.datasetMinNumImages());
    assertTrue(c.perTreeResultsEnabled());
    assertEquals(TimeDuration.seconds(9), c.maxProcessRunTime());
    assertEquals(TimeDuration.seconds(10), c.processSupervisorPeriod());
    assertTrue((new BigDecimal("11")).compareTo(c.maxRefinedDetDistDelta()) == 0);
    assertEquals(12, c.numThreadsPerProcessJob());
    assertEquals("d", c.excludeDirPat().pattern());
    assertEquals(Arrays.asList("e"), c.postProcessHook());
  }

  @Test
  public void testDefaults_gettersGetOverrides() {
    AapConfiguration defaults = new AapConfiguration(null, 1, 2, 3, 4, Boolean.TRUE,
        TimeDuration.seconds(5), 6, Boolean.FALSE, Pattern.compile("a"), Pattern.compile("b"),
        Pattern.compile("c"), "processing1", TimeDuration.seconds(7), 8, Boolean.TRUE,
        TimeDuration.seconds(9), TimeDuration.seconds(10), new BigDecimal("11"), 12,
        Pattern.compile("d"), Arrays.asList("e"));
    AapConfiguration c = new AapConfiguration(defaults, 21, 22, 23, 24, Boolean.FALSE,
        TimeDuration.seconds(25), 26, Boolean.TRUE, Pattern.compile("na"), Pattern.compile("nb"),
        Pattern.compile("nc"), "processing2", TimeDuration.seconds(27), 28, Boolean.FALSE,
        TimeDuration.seconds(29), TimeDuration.seconds(30), new BigDecimal("31"), 32,
        Pattern.compile("nd"), Arrays.asList("ne"));
    assertEquals(21, c.maxNumProcessJobs());
    assertEquals(22, c.maxNumIndexJobs());
    assertEquals(23, c.maxNumRegisterJobs());
    assertEquals(24, c.maxNumDirChangeJobs());
    assertFalse(c.fileSystemPollEnabled());
    assertEquals(TimeDuration.seconds(25), c.fileSystemPollPeriod());
    assertEquals(26, c.fileSystemPollMaxNumJobs());
    assertTrue(c.fileSystemPollMetadataEnabled());
    assertEquals("na", c.processingDirPat().pattern());
    assertEquals("nb", c.diffCenterImagePat().pattern());
    assertEquals("nc", c.imagePat().pattern());
    assertEquals("processing2", c.processingDirName());
    assertEquals(TimeDuration.seconds(27), c.datasetSettleTime());
    assertEquals(28, c.datasetMinNumImages());
    assertFalse(c.perTreeResultsEnabled());
    assertEquals(TimeDuration.seconds(29), c.maxProcessRunTime());
    assertEquals(TimeDuration.seconds(30), c.processSupervisorPeriod());
    assertTrue((new BigDecimal("31")).compareTo(c.maxRefinedDetDistDelta()) == 0);
    assertEquals(32, c.numThreadsPerProcessJob());
    assertEquals("nd", c.excludeDirPat().pattern());
    assertEquals(Arrays.asList("ne"), c.postProcessHook());
  }

  @Test
  public void testDefaults_setDefaults() {
    AapConfiguration defaults = new AapConfiguration(null, 1, 2, 3, 4, Boolean.TRUE,
        TimeDuration.seconds(5), 6, Boolean.FALSE, Pattern.compile("a"), Pattern.compile("b"),
        Pattern.compile("c"), "processing1", TimeDuration.seconds(7), 8, Boolean.TRUE,
        TimeDuration.seconds(9), TimeDuration.seconds(10), new BigDecimal("11"), 12,
        Pattern.compile("d"), Arrays.asList("e"));
    AapConfiguration c = new AapConfiguration(defaults, null, null, null, null, null, null, null,
        null, null, null, null, null, null, null, null, null, null, null, null, null, null);
    defaults = new AapConfiguration(null, 21, 22, 23, 24, Boolean.FALSE, TimeDuration.seconds(25),
        26, Boolean.TRUE, Pattern.compile("na"), Pattern.compile("nb"), Pattern.compile("nc"),
        "processing2", TimeDuration.seconds(27), 28, Boolean.FALSE, TimeDuration.seconds(29),
        TimeDuration.seconds(30), new BigDecimal("31"), 32, Pattern.compile("nd"),
        Arrays.asList("ne"));
    c = c.defaults(defaults);
    assertEquals(21, c.maxNumProcessJobs());
    assertEquals(22, c.maxNumIndexJobs());
    assertEquals(23, c.maxNumRegisterJobs());
    assertEquals(24, c.maxNumDirChangeJobs());
    assertFalse(c.fileSystemPollEnabled());
    assertEquals(TimeDuration.seconds(25), c.fileSystemPollPeriod());
    assertEquals(26, c.fileSystemPollMaxNumJobs());
    assertTrue(c.fileSystemPollMetadataEnabled());
    assertEquals("na", c.processingDirPat().pattern());
    assertEquals("nb", c.diffCenterImagePat().pattern());
    assertEquals("nc", c.imagePat().pattern());
    assertEquals("processing2", c.processingDirName());
    assertEquals(TimeDuration.seconds(27), c.datasetSettleTime());
    assertEquals(28, c.datasetMinNumImages());
    assertFalse(c.perTreeResultsEnabled());
    assertEquals(TimeDuration.seconds(29), c.maxProcessRunTime());
    assertEquals(TimeDuration.seconds(30), c.processSupervisorPeriod());
    assertTrue((new BigDecimal("31")).compareTo(c.maxRefinedDetDistDelta()) == 0);
    assertEquals(32, c.numThreadsPerProcessJob());
    assertEquals("nd", c.excludeDirPat().pattern());
    assertEquals(Arrays.asList("ne"), c.postProcessHook());
  }
}
