/*
 * Copyright (c) 2014 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * Tests {@link TimeDuration}.
 */
public class TimeDurationTest {
  public TimeDurationTest() {
    super();
  }

  @Test
  public void testEquals() {
    assertEquals(TimeDuration.seconds(0L), TimeDuration.seconds(0L));
    assertEquals(TimeDuration.seconds(5L), TimeDuration.seconds(5L));
    assertNotEquals(TimeDuration.seconds(5L), TimeDuration.seconds(6L));
    assertEquals(TimeDuration.minutes(5L), TimeDuration.minutes(5L));
    assertNotEquals(TimeDuration.seconds(5L), TimeDuration.minutes(5L));
    assertNotEquals(TimeDuration.seconds(5L), TimeDuration.milliseconds(5000L));
  }

  @Test
  public void testCompareTo() {
    assertEquals(0, TimeDuration.seconds(0L).compareTo(TimeDuration.seconds(0L)));
    assertEquals(0, TimeDuration.seconds(5L).compareTo(TimeDuration.seconds(5L)));
    assertTrue(TimeDuration.seconds(5L).compareTo(TimeDuration.seconds(6L)) < 0);
    assertEquals(0, TimeDuration.minutes(5L).compareTo(TimeDuration.minutes(5L)));
    assertTrue(TimeDuration.minutes(5L).compareTo(TimeDuration.seconds(5L)) > 0);
    assertEquals(0, TimeDuration.seconds(5L).compareTo(TimeDuration.milliseconds(5000L)));
  }
}
