/*
 * Copyright (c) 2017 J. Lewis Muir <jlmuir@imca-cat.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.imca_cat.aaproc;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

/**
 * Tests {@link Utilities}.
 */
public class UtilitiesTest {
  public UtilitiesTest() {
    super();
  }

  @Test(expected = NullPointerException.class)
  public void testDatasetFileBaseName_null() {
    Utilities.datasetFileBaseName(null);
  }

  @Test
  public void testDatasetFileBaseName_underscore() {
    assertEquals("image_", Utilities.datasetFileBaseName("image_0001.cbf"));
    assertEquals("image_", Utilities.datasetFileBaseName("image_x.cbf"));
    assertEquals("image_x_", Utilities.datasetFileBaseName("image_x_0001.cbf"));
    assertEquals("image_2_", Utilities.datasetFileBaseName("image_2_0001.cbf"));
    assertEquals("image_", Utilities.datasetFileBaseName("image_"));
    assertEquals("image_", Utilities.datasetFileBaseName("image_."));
    assertEquals("_", Utilities.datasetFileBaseName("_"));
    assertEquals("a1_", Utilities.datasetFileBaseName("a1_master.h5"));
  }

  @Test
  public void testDatasetFileBaseName_noUnderscoreWithMasterDotH5() {
    assertEquals("a1.", Utilities.datasetFileBaseName("a1.master.h5"));
    assertEquals("X", Utilities.datasetFileBaseName("Xmaster.h5"));
  }

  @Test
  public void testDatasetFileBaseName_noUnderscoreWithDigits() {
    assertEquals("image", Utilities.datasetFileBaseName("image0001.cbf"));
    assertEquals("image", Utilities.datasetFileBaseName("image0001."));
    assertEquals("image", Utilities.datasetFileBaseName("image0001"));
    assertEquals("image5a", Utilities.datasetFileBaseName("image5a0001.cbf"));
    assertEquals("image5a", Utilities.datasetFileBaseName("image5a0001."));
    assertEquals("image5a", Utilities.datasetFileBaseName("image5a0001"));
    assertEquals("", Utilities.datasetFileBaseName("0001"));
    /*
     * Has a Unicode code point requiring two UTF-16 code units before the
     * digit group.
     */
    assertEquals("image\uD801\uDC00", Utilities.datasetFileBaseName("image\uD801\uDC000001"));
    /*
     * Has a Unicode code point requiring two UTF-16 code units before the
     * digit group, with an extension.
     */
    assertEquals("image\uD801\uDC00", Utilities.datasetFileBaseName("image\uD801\uDC000001.cbf"));
  }

  @Test
  public void testDatasetFileBaseName_NoMatch() {
    assertEquals("", Utilities.datasetFileBaseName(""));
    assertEquals("x", Utilities.datasetFileBaseName("x"));
    assertEquals("image.cbf", Utilities.datasetFileBaseName("image.cbf"));
    assertEquals("image-a.cbf", Utilities.datasetFileBaseName("image-a.cbf"));
    assertEquals("image0001a", Utilities.datasetFileBaseName("image0001a"));
    /* Has a Unicode code point requiring two UTF-16 code units at the end. */
    assertEquals("image\uD801\uDC00", Utilities.datasetFileBaseName("image\uD801\uDC00"));
  }
}
